==> h2o-ext-xgboost-3.24.0.2-sources.jar: ml/dmlc/xgboost4j/java/PredictorFactory.java <==
package ml.dmlc.xgboost4j.java;

import biz.k11i.xgboost.Predictor;
import biz.k11i.xgboost.config.PredictorConfiguration;
import biz.k11i.xgboost.tree.RegTree;
import biz.k11i.xgboost.tree.RegTreeFactory;
import biz.k11i.xgboost.util.ModelReader;
import water.util.Log;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteOrder;

public class PredictorFactory {

  public static Predictor makePredictor(byte[] boosterBytes) {
    return makePredictor(boosterBytes, true);
  }

  public static Predictor makePredictor(byte[] boosterBytes, boolean scoringOnly) {
    PredictorConfiguration.Builder bldr = PredictorConfiguration.builder();
    if (scoringOnly && unsafeTreesSupported()) {
      Log.warn("XGBoost Predictor is using EXPERIMENTAL scoring implementation!");
      bldr.regTreeFactory(UnsafeRegTreeFactory.INSTANCE);
    }
    PredictorConfiguration cfg = bldr.build();
    try (InputStream is = new ByteArrayInputStream(boosterBytes)) {
      return new Predictor(is, cfg);
    } catch (IOException e) {
      throw new IllegalStateException(e);
    }
  }

  private static boolean unsafeTreesSupported() {
    // XGBoost Predictor uses LE, we can only use our scoring if the system has the same endianness
    return ByteOrder.nativeOrder().equals(ByteOrder.LITTLE_ENDIAN);
  }

  private static class UnsafeRegTreeFactory implements RegTreeFactory {
    private static final UnsafeRegTreeFactory INSTANCE = new UnsafeRegTreeFactory();
    @Override
    public RegTree loadTree(ModelReader reader) throws IOException {
      return new XGBoostRegTree(reader);
    }
  }

}

==> h2o-ext-xgboost-3.24.0.4-sources.jar: ml/dmlc/xgboost4j/java/PredictorFactory.java <==
package ml.dmlc.xgboost4j.java;

import biz.k11i.xgboost.Predictor;
import biz.k11i.xgboost.config.PredictorConfiguration;
import biz.k11i.xgboost.tree.RegTree;
import biz.k11i.xgboost.tree.RegTreeFactory;
import biz.k11i.xgboost.util.ModelReader;
import hex.genmodel.algos.xgboost.XGBoostJavaObjFunRegistration;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteOrder;

public class PredictorFactory {
  
  static {
    XGBoostJavaObjFunRegistration.register();
  }
  
  public static Predictor makePredictor(byte[] boosterBytes) {
    return makePredictor(boosterBytes, true);
  }

  public static Predictor makePredictor(byte[] boosterBytes, boolean scoringOnly) {
    PredictorConfiguration.Builder bldr = PredictorConfiguration.builder();
    if (scoringOnly && unsafeTreesSupported()) {
      bldr.regTreeFactory(UnsafeRegTreeFactory.INSTANCE);
    }
    PredictorConfiguration cfg = bldr.build();
    try (InputStream is = new ByteArrayInputStream(boosterBytes)) {
      return new Predictor(is, cfg);
    } catch (IOException e) {
      throw new IllegalStateException(e);
    }
  }

  private static boolean unsafeTreesSupported() {
    // XGBoost Predictor uses LE, we can only use our scoring if the system has the same endianness
    return ByteOrder.nativeOrder().equals(ByteOrder.LITTLE_ENDIAN);
  }

  private static class UnsafeRegTreeFactory implements RegTreeFactory {
    private static final UnsafeRegTreeFactory INSTANCE = new UnsafeRegTreeFactory();
    @Override
    public RegTree loadTree(ModelReader reader) throws IOException {
      return new XGBoostRegTree(reader);
    }
  }

}
